package com.ruoyi.system.mapper;

import java.util.List;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.ruoyi.system.domain.TdPropertyInfo;

/**
 * 资产管理Mapper接口
 * 
 * @author ruoyi
 * @date 2024-04-29
 */
public interface TdPropertyInfoMapper extends BaseMapper<TdPropertyInfo>
{
    /**
     * 查询资产管理
     * 
     * @param id 资产管理主键
     * @return 资产管理
     */
    public TdPropertyInfo selectTdPropertyInfoById(String id);

    public List<TdPropertyInfo> selectTdPropertyInfoByUseId(String id);

    /**
     * 查询资产管理列表
     * 
     * @param tdPropertyInfo 资产管理
     * @return 资产管理集合
     */
    public List<TdPropertyInfo> selectTdPropertyInfoList(TdPropertyInfo tdPropertyInfo);

    /**
     * 新增资产管理
     * 
     * @param tdPropertyInfo 资产管理
     * @return 结果
     */
    public int insertTdPropertyInfo(TdPropertyInfo tdPropertyInfo);

    /**
     * 修改资产管理
     * 
     * @param tdPropertyInfo 资产管理
     * @return 结果
     */
    public int updateTdPropertyInfo(TdPropertyInfo tdPropertyInfo);

    /**
     * 删除资产管理
     * 
     * @param id 资产管理主键
     * @return 结果
     */
    public int deleteTdPropertyInfoById(String id);

    /**
     * 批量删除资产管理
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTdPropertyInfoByIds(String[] ids);
}
